# Changelog

## 1.31.0.post1 (2022-08-15)
- Use setuptools scm for versioning
- Add Python 3.10 wheels

## 1.31.0 (2020-10-14)
- Support multi-line thumb and icon labels

## 1.30.2 (2020-10-13)
- Improve build pipeline

## 1.30.1 (2020-07-16)
- Add CI build support and PyPI deployment
- Moved pyglui package to src/ directory
- Added basic tests

## 1.30.0 (2020-07-09)
- Add `Color_Legend` ui element
- Fix Separator and Info_Text outline padding

## 1.29.2 (2020-07-08)
- Update to pupil-icon-font 0.0.4 (includes imu_timeline icon)
- Maintenance and build pipeline updates
